@@ -33,6 +33,9 @@ args <- list(x = 42, y = 12)
 v0 <- do.call(function(x, y) a * (x - y), args = args)
 
 for (cores in 1:availCores) {
+  ## Speed up CRAN checks: Skip on CRAN Windows 32-bit
+  if (!fullTest && isWin32) next
+  
   message(sprintf("Testing with %d cores ...", cores))
   options(mc.cores = cores)
   strategies <- supportedStrategies(cores)
@@ -104,17 +107,21 @@ message("- futureCall() - mix of strategies, cores, lazy and globals ... DONE")
 
 message("- futureCall() - bug fixes")
 
+plan(sequential)
+plan(cluster, workers = 1L)
+
 fcn <- function() a
 v <- tryCatch(local({
-  a <- 42
-  f <- futureCall(fcn, args = list(), globals = "a")
+  abc <- 42
+  f <- futureCall(fcn, args = list(), globals = "abc")
   value(f)
 }), error = identity)
 
 ## Bug #262: the above used to return NULL
 stopifnot(!is.null(v))
 
-## Bug: Now, it instead fails, because it cannot find 'a'
+## Bug: Now, it instead fails, because it cannot find 'abc'
+print(v)
 stopifnot(inherits(v, "error"))
 
 message("*** futureCall() ... DONE")
